@@ -2,9 +2,12 @@ import os
 import time
 from enum import Enum
 from functools import partial
+from platform import node
 
 import structlog
+from structlog.contextvars import bind_contextvars, clear_contextvars, merge_contextvars, unbind_contextvars
 from structlog.exceptions import DropEvent
+from ulid import ULID
 
 
 class LogLevel(Enum):
@@ -24,6 +27,11 @@ class LogLevel(Enum):
 
 
 current_level = LogLevel.debug
+structlog.PrintLogger.trace = structlog.PrintLogger.msg
+pid = os.getpid()
+hostname = node()
+ulid = str(ULID())
+clear_contextvars()
 
 
 def set_level(level: LogLevel):
@@ -35,6 +43,24 @@ def set_level(level: LogLevel):
     current_level = level
 
 
+def set_contextvars(key_value: dict):
+    """Set the context variables.
+
+    Args:
+        key_value (dict): A dictionnary of key-value pairs.
+    """
+    bind_contextvars(**key_value)
+
+
+def remove_contextvars(keys):
+    """Remove the context variables.
+
+    Args:
+        keys (list): A list of keys.
+    """
+    unbind_contextvars(*keys)
+
+
 def level_filter(_, __, event_dict: dict):
     """
     Silently drop logs lower than the set level.
@@ -44,8 +70,6 @@ def level_filter(_, __, event_dict: dict):
     return event_dict
 
 
-structlog.PrintLogger.trace = structlog.PrintLogger.msg
-pid = os.getpid()
 # This is a standard format for the function so it needs all three arguments
 # Even thought we do not use them
 # pylint: disable=unused-argument
@@ -68,6 +92,8 @@ def add_default_keys(current_logger, method_name: str, event_dict: dict):
     # Standard keys that need to be added
     event_dict["v"] = 1
     event_dict["pid"] = pid
+    event_dict["hostname"] = hostname
+    event_dict["id"] = ulid
     # Remap event -> msg
     event_dict["msg"] = event_dict["event"]
     del event_dict["event"]
@@ -76,13 +102,13 @@ def add_default_keys(current_logger, method_name: str, event_dict: dict):
 
 structlog.configure(
     processors=[
+        merge_contextvars,
         add_default_keys,
         level_filter,
         structlog.processors.StackInfoRenderer(),
         structlog.processors.format_exc_info,
         structlog.processors.JSONRenderer(),
-    ],
-    context_class=structlog.threadlocal.wrap_dict(dict),
+    ]
 )
 
 
