@@ -1,11 +1,7 @@
-"""
-Tests for the hello() function.
-"""
-
 import json
 import os
 
-from .logger import LogLevel, get_log, set_level
+from .logger import LogLevel, get_log, remove_contextvars, set_contextvars, set_level
 
 
 def test_hello_without_name():
@@ -41,3 +37,22 @@ def test_timestamp(capsys):
     log = json.loads(stdout)
 
     assert log["time"] - systime < 1000
+
+
+def test_contextvars(capsys):
+    set_contextvars({"ip": "192.168.0.2", "country": "NZ"})
+
+    get_log().trace("abc")
+    stdout, _ = capsys.readouterr()
+    log = json.loads(stdout)
+
+    assert log["ip"] == "192.168.0.2"
+    assert log["country"] == "NZ"
+
+    remove_contextvars(["country"])
+
+    get_log().trace("def")
+    stdout, _ = capsys.readouterr()
+    log = json.loads(stdout)
+
+    assert not "country" in log
